

from tkinter import *
import math

class MainApp(object):
    def __init__(self, parent):
        self.parent = parent
        self.maxlevel = 1
        
        self.top_frame = Frame(self.parent)
        self.top_frame.pack(side=TOP)
        self.bottom_frame = Frame(self.parent)
        self.bottom_frame.pack(side=BOTTOM)
        self.canvas = Canvas(self.top_frame, width=600, height=600, background="white")        
        self.canvas.pack()
        
        self.info_text = Canvas(self.bottom_frame, width=100, height=50, background="white")
        self.info_text.pack(side=LEFT)
        
        self.info_text.create_text( (50,25), text=self.get_level())
        
        self.restart = Button(self.bottom_frame,text="Draw",command=self.draw)
        self.restart.pack(side=LEFT)
        
        self.increment = Button(self.bottom_frame,text="Increment",command=self.increment)
        self.increment.pack(side=LEFT)

        self.decrement = Button(self.bottom_frame,text="Decrement", command=self.decrement)
        self.decrement.pack(side=LEFT)
        
        self.quit = Button(self.bottom_frame,text="Quit", command= self.quit)
        self.quit.pack(side=RIGHT)
        self.is_stopped = False
        
    def draw(self):
        self.canvas.delete("all")
        self.sierpinski( (0,600), \
                         (300,600-300*math.sqrt(3)), \
                         (600,600),
                         self.maxlevel)
        
    def sierpinski(self, left, mid, right, level):
        midleft = (left[0]+mid[0])//2, (left[1]+mid[1])//2
        midright = (right[0]+mid[0])//2, (right[1]+mid[1])//2
        midbottom = (left[0]+right[0])//2, (left[1]+right[1])//2        
        if level <= 1:
            self.canvas.create_polygon([left, mid, right], \
                                       fill = "white")
           
            self.canvas.create_polygon([left, midleft, midbottom],\
                                       fill = "red")
            self.canvas.create_polygon([midleft, mid, midright],\
                                       fill = "red")
            self.canvas.create_polygon([midbottom, midright, right],\
                                       fill = "red")
        else:
            self.sierpinski(left, midleft, midbottom, level-1)
            self.sierpinski(midleft, mid, midright, level-1)
            self.sierpinski(midbottom, midright, right, level-1)
            
            
        
    def get_level(self):
        return "Maxlevel: {}".format(self.maxlevel)
    
    def increment(self):
        self.maxlevel = min(self.maxlevel+1, 10)
        self.info_text.delete("all")
        self.info_text.create_text( (50,25), text=self.get_level())
        
    def decrement(self):
        self.maxlevel = max(self.maxlevel-1, 1)
        self.info_text.delete("all")        
        self.info_text.create_text( (50,25), text=self.get_level())
        
        

    def quit(self):
        self.is_stopped = True
        self.parent.destroy()
        
    
if __name__ == "__main__":        
        
    root = Tk()
    root.title("Sierpinski")
    sierApp = MainApp(root)
    root.mainloop()
    
 